@@ -319,16 +319,14 @@ class LoginMixin(PreLoginFlowMixin, PostLoginFlowMixin):
             A boolean value
         """
         assert isinstance(sessionid, str) and len(sessionid) > 30, "Invalid sessionid"
-        self.settings = {"cookies": {"sessionid": sessionid}}
+        self.settings["cookies"] = {"sessionid": sessionid}
         self.init()
         user_id = re.search(r"^\d+", sessionid).group()
-
         self.authorization_data = {
             "ds_user_id": user_id,
             "sessionid": sessionid,
             "should_use_header_over_cookies": True
         }
-
         try:
             user = self.user_info_v1(int(user_id))
         except (PrivateError, ValidationError):
